@@ -6,7 +6,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2019	PgPool Global Development Group
+ * Copyright (c) 2003-2021	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -33,7 +33,7 @@
 /*
  * watchdog
  */
-#define WD_MAX_HOST_NAMELEN (128)
+#define WD_MAX_HOST_NAMELEN MAX_FDQN_HOSTNAME_LEN
 #define WD_MAX_NODE_NAMELEN (WD_MAX_HOST_NAMELEN + POOLCONFIG_MAXPORTLEN + sizeof(((struct utsname *)NULL)->sysname) + sizeof(((struct utsname *)NULL)->nodename) + 3)
 #define WD_MAX_PATH_LEN (128)
 #define MAX_WATCHDOG_NUM (128)
